# Change Log

<!-- <START NEW CHANGELOG ENTRY> -->

## 2.16.6

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.16.5...b8135b4a661f75560d39b52aab90f3e951884c39))

### Bugs fixed

- Restore print outputs in process [#357](https://github.com/jupyterlab/jupyterlab_server/pull/357) ([@blink1073](https://github.com/blink1073))

### Maintenance and upkeep improvements

- Bump tj-actions/changed-files from 34 to 35 [#355](https://github.com/jupyterlab/jupyterlab_server/pull/355) ([@dependabot](https://github.com/dependabot))
- Fix license header job [#354](https://github.com/jupyterlab/jupyterlab_server/pull/354) ([@fcollonval](https://github.com/fcollonval))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-12-08&to=2022-12-23&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-12-08..2022-12-23&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-12-08..2022-12-23&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Adependabot+updated%3A2022-12-08..2022-12-23&type=Issues) | [@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2022-12-08..2022-12-23&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 2.16.5

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.16.4...ee8db6a651c68fc1413935fa1d10d58a38f1ccc1))

### Maintenance and upkeep improvements

- Use pytest-jupyter [#351](https://github.com/jupyterlab/jupyterlab_server/pull/351) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-12-08&to=2022-12-08&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-12-08..2022-12-08&type=Issues)

## 2.16.4

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.16.3...2005945e4cbe81a1d7a52103557cefa6e1283592))

### Maintenance and upkeep improvements

- Add py.typed marker file [#349](https://github.com/jupyterlab/jupyterlab_server/pull/349) ([@blink1073](https://github.com/blink1073))
- Update docutils requirement from \<0.19 to \<0.20 [#348](https://github.com/jupyterlab/jupyterlab_server/pull/348) ([@dependabot](https://github.com/dependabot))
- Update openapi-spec-validator requirement from \<0.5 to \<0.6 [#347](https://github.com/jupyterlab/jupyterlab_server/pull/347) ([@dependabot](https://github.com/dependabot))
- Update mistune requirement from \<1 to \<3 [#345](https://github.com/jupyterlab/jupyterlab_server/pull/345) ([@dependabot](https://github.com/dependabot))
- Update jinja2 requirement from \<3.1.0 to \<3.2.0 [#344](https://github.com/jupyterlab/jupyterlab_server/pull/344) ([@dependabot](https://github.com/dependabot))
- Adopt ruff and address lint [#343](https://github.com/jupyterlab/jupyterlab_server/pull/343) ([@blink1073](https://github.com/blink1073))
- Fixup workflows [#339](https://github.com/jupyterlab/jupyterlab_server/pull/339) ([@blink1073](https://github.com/blink1073))
- CI Cleanup [#337](https://github.com/jupyterlab/jupyterlab_server/pull/337) ([@blink1073](https://github.com/blink1073))

### Documentation improvements

- Update codecov badge [#340](https://github.com/jupyterlab/jupyterlab_server/pull/340) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-11-11&to=2022-12-08&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-11-11..2022-12-08&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-11-11..2022-12-08&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Adependabot+updated%3A2022-11-11..2022-12-08&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Apre-commit-ci+updated%3A2022-11-11..2022-12-08&type=Issues)

## 2.16.3

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.16.2...cdc81451c3f187e8183f2e5b67be2e648501f979))

### Maintenance and upkeep improvements

- Fix handling of jupyter core warning [#335](https://github.com/jupyterlab/jupyterlab_server/pull/335) ([@blink1073](https://github.com/blink1073))
- Increase coverage [#334](https://github.com/jupyterlab/jupyterlab_server/pull/334) ([@blink1073](https://github.com/blink1073))
- Fix license header CI job [#333](https://github.com/jupyterlab/jupyterlab_server/pull/333) ([@fcollonval](https://github.com/fcollonval))
- Bump tj-actions/changed-files from 33 to 34 [#331](https://github.com/jupyterlab/jupyterlab_server/pull/331) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-10-31&to=2022-11-11&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-10-31..2022-11-11&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-10-31..2022-11-11&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Adependabot+updated%3A2022-10-31..2022-11-11&type=Issues) | [@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2022-10-31..2022-11-11&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Apre-commit-ci+updated%3A2022-10-31..2022-11-11&type=Issues)

## 2.16.2

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.16.1...dbf016fb5e312b3c03e8438a80d6df4f40de48e3))

### Bugs fixed

- Terminals availability is not the responsibility of JupyterLab [#330](https://github.com/jupyterlab/jupyterlab_server/pull/330) ([@fcollonval](https://github.com/fcollonval))

### Maintenance and upkeep improvements

- Bump tj-actions/changed-files from 32 to 33 [#328](https://github.com/jupyterlab/jupyterlab_server/pull/328) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-10-19&to=2022-10-31&type=c))

[@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-10-19..2022-10-31&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Adependabot+updated%3A2022-10-19..2022-10-31&type=Issues) | [@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2022-10-19..2022-10-31&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Apre-commit-ci+updated%3A2022-10-19..2022-10-31&type=Issues)

## 2.16.1

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.16.0...11e0bb82dbaeb0cb45d16e18d80220003a15d459))

### Maintenance and upkeep improvements

- Prep for using releaser [#327](https://github.com/jupyterlab/jupyterlab_server/pull/327) ([@blink1073](https://github.com/blink1073))
- Maintenance cleanup [#325](https://github.com/jupyterlab/jupyterlab_server/pull/325) ([@blink1073](https://github.com/blink1073))
- Bump actions/upload-artifact from 2 to 3 [#322](https://github.com/jupyterlab/jupyterlab_server/pull/322) ([@dependabot](https://github.com/dependabot))
- Bump actions/download-artifact from 2 to 3 [#321](https://github.com/jupyterlab/jupyterlab_server/pull/321) ([@dependabot](https://github.com/dependabot))
- Bump actions/checkout from 2 to 3 [#320](https://github.com/jupyterlab/jupyterlab_server/pull/320) ([@dependabot](https://github.com/dependabot))
- Bump tj-actions/changed-files from 24 to 32 [#319](https://github.com/jupyterlab/jupyterlab_server/pull/319) ([@dependabot](https://github.com/dependabot))
- Fix workflows and add new ones [#318](https://github.com/jupyterlab/jupyterlab_server/pull/318) ([@fcollonval](https://github.com/fcollonval))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-10-13&to=2022-10-19&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-10-13..2022-10-19&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-10-13..2022-10-19&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Adependabot+updated%3A2022-10-13..2022-10-19&type=Issues) | [@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2022-10-13..2022-10-19&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Apre-commit-ci+updated%3A2022-10-13..2022-10-19&type=Issues)

## 2.16.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.15.1...c278cb9bbda81a2730d1198f0a5fc708a18506d9))

### Enhancements made

- raise jupyter_server pin to include 2.x [#302](https://github.com/jupyterlab/jupyterlab_server/pull/302) ([@Zsailer](https://github.com/Zsailer))

### Maintenance and upkeep improvements

- CI Cleanup [#316](https://github.com/jupyterlab/jupyterlab_server/pull/316) ([@blink1073](https://github.com/blink1073))
- Ignore warnings in prerelease test [#312](https://github.com/jupyterlab/jupyterlab_server/pull/312) ([@blink1073](https://github.com/blink1073))
- Clean up pyproject and ci [#306](https://github.com/jupyterlab/jupyterlab_server/pull/306) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-08-23&to=2022-10-13&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-08-23..2022-10-13&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-08-23..2022-10-13&type=Issues) | [@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2022-08-23..2022-10-13&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Apre-commit-ci+updated%3A2022-08-23..2022-10-13&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3AZsailer+updated%3A2022-08-23..2022-10-13&type=Issues)

## 2.16.0rc0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.15.1...7d83684f3f94724c977692c2785d5ad81fac231e))

### Enhancements made

- raise jupyter_server pin to include 2.x [#302](https://github.com/jupyterlab/jupyterlab_server/pull/302) ([@Zsailer](https://github.com/Zsailer))

### Maintenance and upkeep improvements

- \[pre-commit.ci\] pre-commit autoupdate [#301](https://github.com/jupyterlab/jupyterlab_server/pull/301) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#300](https://github.com/jupyterlab/jupyterlab_server/pull/300) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-08-23&to=2022-09-09&type=c))

[@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-08-23..2022-09-09&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Apre-commit-ci+updated%3A2022-08-23..2022-09-09&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3AZsailer+updated%3A2022-08-23..2022-09-09&type=Issues)

## 2.15.1

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.15.0...6de991c68abad7041581dd5a7c292194d3b2dea7))

### Maintenance and upkeep improvements

- Add fix license header job [#298](https://github.com/jupyterlab/jupyterlab_server/pull/298) ([@fcollonval](https://github.com/fcollonval))
- \[pre-commit.ci\] pre-commit autoupdate [#297](https://github.com/jupyterlab/jupyterlab_server/pull/297) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Ignore deprecationwarning from jsonschema [#295](https://github.com/jupyterlab/jupyterlab_server/pull/295) ([@blink1073](https://github.com/blink1073))
- \[pre-commit.ci\] pre-commit autoupdate [#294](https://github.com/jupyterlab/jupyterlab_server/pull/294) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#293](https://github.com/jupyterlab/jupyterlab_server/pull/293) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#291](https://github.com/jupyterlab/jupyterlab_server/pull/291) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#290](https://github.com/jupyterlab/jupyterlab_server/pull/290) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#289](https://github.com/jupyterlab/jupyterlab_server/pull/289) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Documentation improvements

- Only use `conda-forge` and not defaults for RTD [#296](https://github.com/jupyterlab/jupyterlab_server/pull/296) ([@afshin](https://github.com/afshin))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-07-05&to=2022-08-23&type=c))

[@afshin](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Aafshin+updated%3A2022-07-05..2022-08-23&type=Issues) | [@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-07-05..2022-08-23&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-07-05..2022-08-23&type=Issues) | [@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2022-07-05..2022-08-23&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Apre-commit-ci+updated%3A2022-07-05..2022-08-23&type=Issues)

## 2.15.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.14.0...2d6ff4077a58bb9ac1531c4a7ad7669163e0ec99))

### Maintenance and upkeep improvements

- \[pre-commit.ci\] pre-commit autoupdate [#287](https://github.com/jupyterlab/jupyterlab_server/pull/287) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#286](https://github.com/jupyterlab/jupyterlab_server/pull/286) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Suppress tornado 6.2 beta warnings [#285](https://github.com/jupyterlab/jupyterlab_server/pull/285) ([@blink1073](https://github.com/blink1073))
- \[pre-commit.ci\] pre-commit autoupdate [#284](https://github.com/jupyterlab/jupyterlab_server/pull/284) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#283](https://github.com/jupyterlab/jupyterlab_server/pull/283) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Add compat for openapi-core 0.15 [#281](https://github.com/jupyterlab/jupyterlab_server/pull/281) ([@blink1073](https://github.com/blink1073))
- \[pre-commit.ci\] pre-commit autoupdate [#280](https://github.com/jupyterlab/jupyterlab_server/pull/280) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#279](https://github.com/jupyterlab/jupyterlab_server/pull/279) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#277](https://github.com/jupyterlab/jupyterlab_server/pull/277) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-05-18&to=2022-07-05&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-05-18..2022-07-05&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-05-18..2022-07-05&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Apre-commit-ci+updated%3A2022-05-18..2022-07-05&type=Issues)

## 2.14.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.13.0...faaf10cbe5abcfa5e3f0e3f7a491d651ed998a26))

### Bugs fixed

- proper setup for the fallback logger [#269](https://github.com/jupyterlab/jupyterlab_server/pull/269) ([@rvalieris](https://github.com/rvalieris))

### Maintenance and upkeep improvements

- \[pre-commit.ci\] pre-commit autoupdate [#275](https://github.com/jupyterlab/jupyterlab_server/pull/275) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Switch to hatch backend [#274](https://github.com/jupyterlab/jupyterlab_server/pull/274) ([@blink1073](https://github.com/blink1073))
- \[pre-commit.ci\] pre-commit autoupdate [#272](https://github.com/jupyterlab/jupyterlab_server/pull/272) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Switch to flit build backend [#271](https://github.com/jupyterlab/jupyterlab_server/pull/271) ([@blink1073](https://github.com/blink1073))
- Allow bot PRs to be automatically labeled [#270](https://github.com/jupyterlab/jupyterlab_server/pull/270) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-04-19&to=2022-05-18&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-04-19..2022-05-18&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-04-19..2022-05-18&type=Issues) | [@kloczek](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Akloczek+updated%3A2022-04-19..2022-05-18&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Apre-commit-ci+updated%3A2022-04-19..2022-05-18&type=Issues) | [@rvalieris](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Arvalieris+updated%3A2022-04-19..2022-05-18&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Awelcome+updated%3A2022-04-19..2022-05-18&type=Issues)

## 2.13.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.12.0...5c123d20b8c1287b596eb50e18d127a851395840))

### Bugs fixed

- Audit uses of print [#261](https://github.com/jupyterlab/jupyterlab_server/pull/261) ([@blink1073](https://github.com/blink1073))

### Maintenance and upkeep improvements

- \[pre-commit.ci\] pre-commit autoupdate [#266](https://github.com/jupyterlab/jupyterlab_server/pull/266) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#265](https://github.com/jupyterlab/jupyterlab_server/pull/265) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Switch to importlib.metadata to list entry points [#264](https://github.com/jupyterlab/jupyterlab_server/pull/264) ([@fcollonval](https://github.com/fcollonval))
- Make some pre-commit hooks manual [#263](https://github.com/jupyterlab/jupyterlab_server/pull/263) ([@blink1073](https://github.com/blink1073))
- \[pre-commit.ci\] pre-commit autoupdate [#262](https://github.com/jupyterlab/jupyterlab_server/pull/262) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Add flake8 and handle warnings in tests [#259](https://github.com/jupyterlab/jupyterlab_server/pull/259) ([@blink1073](https://github.com/blink1073))
- Add git-blame-ignore-revs [#258](https://github.com/jupyterlab/jupyterlab_server/pull/258) ([@blink1073](https://github.com/blink1073))
- Apply Autoformats [#257](https://github.com/jupyterlab/jupyterlab_server/pull/257) ([@blink1073](https://github.com/blink1073))
- Add initial pre-commit [#256](https://github.com/jupyterlab/jupyterlab_server/pull/256) ([@blink1073](https://github.com/blink1073))
- update URLs, metadata, extras in setup.cfg [#255](https://github.com/jupyterlab/jupyterlab_server/pull/255) ([@bollwyvl](https://github.com/bollwyvl))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-03-28&to=2022-04-19&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-03-28..2022-04-19&type=Issues) | [@bollwyvl](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Abollwyvl+updated%3A2022-03-28..2022-04-19&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-03-28..2022-04-19&type=Issues) | [@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2022-03-28..2022-04-19&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Apre-commit-ci+updated%3A2022-03-28..2022-04-19&type=Issues)

## 2.12.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.11.2...d927c4cfcf75e3e61a9c1a37b46e68219bb2a324))

### Enhancements made

- Make openapi optional and lazy [#253](https://github.com/jupyterlab/jupyterlab_server/pull/253) ([@blink1073](https://github.com/blink1073))
- Adds notebook_starts_kernel option to make "canStartKernel" configurable [#248](https://github.com/jupyterlab/jupyterlab_server/pull/248) ([@jweill-aws](https://github.com/jweill-aws))
- Clean up tests and add public openapi_spec [#247](https://github.com/jupyterlab/jupyterlab_server/pull/247) ([@blink1073](https://github.com/blink1073))

### Maintenance and upkeep improvements

- Pin jinja for docs [#252](https://github.com/jupyterlab/jupyterlab_server/pull/252) ([@blink1073](https://github.com/blink1073))
- More CI Cleanup [#249](https://github.com/jupyterlab/jupyterlab_server/pull/249) ([@blink1073](https://github.com/blink1073))

### Documentation improvements

- Updates parameter description for notebook_starts_kernel [#250](https://github.com/jupyterlab/jupyterlab_server/pull/250) ([@jweill-aws](https://github.com/jweill-aws))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-03-17&to=2022-03-28&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-03-17..2022-03-28&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-03-17..2022-03-28&type=Issues) | [@jweill-aws](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ajweill-aws+updated%3A2022-03-17..2022-03-28&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Awelcome+updated%3A2022-03-17..2022-03-28&type=Issues)

## 2.11.2

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.11.1...271f61678c43a7856058ef0adb422ed1070d76d6))

### Bugs fixed

- Resolve paths in tests [#245](https://github.com/jupyterlab/jupyterlab_server/pull/245) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-03-16&to=2022-03-17&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-03-16..2022-03-17&type=Issues)

## 2.11.1

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.11.0...681cd7a24fbe6425140d3cb8daabcf4c5f45a069))

### Bugs fixed

- Restore pytest_plugin [#243](https://github.com/jupyterlab/jupyterlab_server/pull/243) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-03-16&to=2022-03-16&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-03-16..2022-03-16&type=Issues)

## 2.11.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.10.3...e004d2d23cb298bc9ae8f1fcb04c47a71cfe7a3a))

### Enhancements made

- Also look in `static` for license files [#238](https://github.com/jupyterlab/jupyterlab_server/pull/238) ([@bollwyvl](https://github.com/bollwyvl))

### Maintenance and upkeep improvements

- Clean up CI [#241](https://github.com/jupyterlab/jupyterlab_server/pull/241) ([@blink1073](https://github.com/blink1073))
- Include Tests in Sdist But Not Wheel [#239](https://github.com/jupyterlab/jupyterlab_server/pull/239) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2022-01-07&to=2022-03-16&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2022-01-07..2022-03-16&type=Issues) | [@bollwyvl](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Abollwyvl+updated%3A2022-01-07..2022-03-16&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2022-01-07..2022-03-16&type=Issues)

## 2.10.3

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.10.2...788e118e25cd7ad29a3041767201a0e3f66ba28e))

### Bugs fixed

- Fix workspace export without arguments [#236](https://github.com/jupyterlab/jupyterlab_server/pull/236) ([@fcollonval](https://github.com/fcollonval))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-12-28&to=2022-01-07&type=c))

[@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2021-12-28..2022-01-07&type=Issues)

## 2.10.2

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.10.1...cbe3b92d732b327a695d832c66f00e096d47ea2b))

### Bugs fixed

- Revert "Delay list -> dict conversation to end (#192)" [#234](https://github.com/jupyterlab/jupyterlab_server/pull/234) ([@blink1073](https://github.com/blink1073))
- Fix issue where preferredPath is incorrectly calculated [#233](https://github.com/jupyterlab/jupyterlab_server/pull/233) ([@mlucool](https://github.com/mlucool))

### Maintenance and upkeep improvements

- Add downstream test workflow [#232](https://github.com/jupyterlab/jupyterlab_server/pull/232) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-12-22&to=2021-12-28&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2021-12-22..2021-12-28&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2021-12-22..2021-12-28&type=Issues) | [@mlucool](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Amlucool+updated%3A2021-12-22..2021-12-28&type=Issues)

## 2.10.1

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.10.0...65027f3ca0a2c5846ba8381c47809e5d04eb05c7))

### Bugs fixed

- Restore back older export for workspaces [#229](https://github.com/jupyterlab/jupyterlab_server/pull/229) ([@fcollonval](https://github.com/fcollonval))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-12-22&to=2021-12-22&type=c))

[@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2021-12-22..2021-12-22&type=Issues)

## 2.10.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.9.0...6fa038f12ad7946e16c5e18665e8a88177080264))

### Enhancements made

- Move workspace management in jupyterlab_server [#227](https://github.com/jupyterlab/jupyterlab_server/pull/227) ([@fcollonval](https://github.com/fcollonval))

### Bugs fixed

- Delay list -> dict conversation to end [#192](https://github.com/jupyterlab/jupyterlab_server/pull/192) ([@vidartf](https://github.com/vidartf))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-12-13&to=2021-12-22&type=c))

[@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2021-12-13..2021-12-22&type=Issues) | [@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2021-12-13..2021-12-22&type=Issues) | [@vidartf](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Avidartf+updated%3A2021-12-13..2021-12-22&type=Issues)

## 2.9.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.8.2...ea75fc04f9a4d29b9c22c9ec769835df3ba6a0e4))

### Enhancements made

- Add `overrides.d` for settings defaults [#224](https://github.com/jupyterlab/jupyterlab_server/pull/224) ([@bollwyvl](https://github.com/bollwyvl))
- Add `page_config_hook` [#220](https://github.com/jupyterlab/jupyterlab_server/pull/220) ([@minrk](https://github.com/minrk))

### Maintenance and upkeep improvements

- Enforce labels on PRs [#221](https://github.com/jupyterlab/jupyterlab_server/pull/221) ([@blink1073](https://github.com/blink1073))
- Fix caching of conda env in CI [#218](https://github.com/jupyterlab/jupyterlab_server/pull/218) ([@blink1073](https://github.com/blink1073))
- `pyproject.toml`: clarify build system version [#222](https://github.com/jupyterlab/jupyterlab_server/pull/222) ([@adamjstewart](https://github.com/adamjstewart))

### Documentation improvements

- Fix typo in README [#216](https://github.com/jupyterlab/jupyterlab_server/pull/216) ([@Mithil467](https://github.com/Mithil467))
- Clean up Readme [#215](https://github.com/jupyterlab/jupyterlab_server/pull/215) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-09-25&to=2021-12-13&type=c))

[@adamjstewart](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Aadamjstewart+updated%3A2021-09-25..2021-12-13&type=Issues) | [@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2021-09-25..2021-12-13&type=Issues) | [@bollwyvl](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Abollwyvl+updated%3A2021-09-25..2021-12-13&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2021-09-25..2021-12-13&type=Issues) | [@minrk](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Aminrk+updated%3A2021-09-25..2021-12-13&type=Issues) | [@Mithil467](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3AMithil467+updated%3A2021-09-25..2021-12-13&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Awelcome+updated%3A2021-09-25..2021-12-13&type=Issues)

## 2.8.2

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.8.1...27cead5e506882c1cf999cb8ca48a94031064c9a))

### Bugs fixed

- Fallback to context-less translation on Python 3.7 [#213](https://github.com/jupyterlab/jupyterlab_server/pull/213) ([@krassowski](https://github.com/krassowski))
- Clean unneeded catch [#210](https://github.com/jupyterlab/jupyterlab_server/pull/210) ([@fcollonval](https://github.com/fcollonval))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-09-07&to=2021-09-25&type=c))

[@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2021-09-07..2021-09-25&type=Issues) | [@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2021-09-07..2021-09-25&type=Issues) | [@krassowski](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Akrassowski+updated%3A2021-09-07..2021-09-25&type=Issues)

## 2.8.1

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.8.0...680f4fe1c8c7d1d7841e14562720d81a27e6d0ad))

### Bugs fixed

- Fall back to `DEFAULT_LOCALE` when translation settings schema is invalid in `get_current_locale` [#207](https://github.com/jupyterlab/jupyterlab_server/pull/207) ([@telamonian](https://github.com/telamonian))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-09-07&to=2021-09-07&type=c))

[@telamonian](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Atelamonian+updated%3A2021-09-07..2021-09-07&type=Issues)

## 2.8.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.7.2...407a8e997825e76b7f9c8992ee03206c21ea0fa0))

### Enhancements made

- Translate settings schema [#205](https://github.com/jupyterlab/jupyterlab_server/pull/205) ([@fcollonval](https://github.com/fcollonval))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-08-23&to=2021-09-07&type=c))

[@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2021-08-23..2021-09-07&type=Issues)

## 2.7.2

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.7.1...1508ff86421f1473ad388ac2d384bf986e326862))

### Bugs fixed

- Do not overwrite capitalization of region names [#202](https://github.com/jupyterlab/jupyterlab_server/pull/202) ([@krassowski](https://github.com/krassowski))

### Maintenance and upkeep improvements

- Use Check Links Action [#201](https://github.com/jupyterlab/jupyterlab_server/pull/201) ([@blink1073](https://github.com/blink1073))

### Documentation improvements

- Recommend `pytest --pyargs jupyterlab_server` [#203](https://github.com/jupyterlab/jupyterlab_server/pull/203) ([@krassowski](https://github.com/krassowski))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-08-17&to=2021-08-23&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2021-08-17..2021-08-23&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2021-08-17..2021-08-23&type=Issues) | [@krassowski](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Akrassowski+updated%3A2021-08-17..2021-08-23&type=Issues)

## 2.7.1

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.7.0...4c5f9c84fa4c1be2267712d2a5f28fe82bdf9047))

### Bugs fixed

- Fix reset user settings if validation failed [#199](https://github.com/jupyterlab/jupyterlab_server/pull/199) ([@fcollonval](https://github.com/fcollonval))

### Maintenance and upkeep improvements

- TST: support openapi-core 0.14 SpecPath [#198](https://github.com/jupyterlab/jupyterlab_server/pull/198) ([@bnavigator](https://github.com/bnavigator))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-08-11&to=2021-08-17&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2021-08-11..2021-08-17&type=Issues) | [@bnavigator](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Abnavigator+updated%3A2021-08-11..2021-08-17&type=Issues) | [@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2021-08-11..2021-08-17&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Awelcome+updated%3A2021-08-11..2021-08-17&type=Issues)

## 2.7.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.6.2...919186b026f8c86f2f14c11318776e272a9dd629))

### Maintenance and upkeep improvements

- Switch to entrypoints package [#187](https://github.com/jupyterlab/jupyterlab_server/pull/187) ([@fcollonval](https://github.com/fcollonval))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-08-03&to=2021-08-11&type=c))

[@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Afcollonval+updated%3A2021-08-03..2021-08-11&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Awelcome+updated%3A2021-08-03..2021-08-11&type=Issues)

## 2.6.2

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.6.1...1ac80fc439a8150de11bc470d370693cf5389781))

### Enhancements made

- PR: Add preferred dir option to config [#190](https://github.com/jupyterlab/jupyterlab_server/pull/190) ([@goanpeca](https://github.com/goanpeca))

### Bugs fixed

- PR: Update new_defaults dictionary instead of copy [#194](https://github.com/jupyterlab/jupyterlab_server/pull/194) ([@goanpeca](https://github.com/goanpeca))

### Other merged PRs

- Update tests workflow [#193](https://github.com/jupyterlab/jupyterlab_server/pull/193) ([@afshin](https://github.com/afshin))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-07-09&to=2021-08-03&type=c))

[@afshin](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Aafshin+updated%3A2021-07-09..2021-08-03&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2021-07-09..2021-08-03&type=Issues) | [@goanpeca](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Agoanpeca+updated%3A2021-07-09..2021-08-03&type=Issues)

## 2.6.1

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.6.0...52f4cf92adb8b6dc3b350ce324619a231a9003ba))

### Enhancements made

- Merge overrides settings if values are dicts [#188](https://github.com/jupyterlab/jupyterlab_server/pull/188) ([@goanpeca](https://github.com/goanpeca))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-06-01&to=2021-07-09&type=c))

[@goanpeca](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Agoanpeca+updated%3A2021-06-01..2021-07-09&type=Issues)

## 2.6.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.5.2...167867d1b49b48735e57106bb13bcc7efd8f2dde))

### Enhancements made

- LicensesManager and API/CLI [#161](https://github.com/jupyterlab/jupyterlab_server/pull/161) ([@bollwyvl](https://github.com/bollwyvl))

### Documentation improvements

- Add changelog for 2.6.0 [#185](https://github.com/jupyterlab/jupyterlab_server/pull/185) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-05-17&to=2021-06-01&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2021-05-17..2021-06-01&type=Issues) | [@bollwyvl](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Abollwyvl+updated%3A2021-05-17..2021-06-01&type=Issues)

## 2.5.1

### Maintenance and upkeep improvements

- Remove Packaging Dependency [#181](https://github.com/jupyterlab/jupyterlab_server/pull/181) ([@jtpio](https://github.com/jtpio))

## 2.5.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/2.4.0...f5009812e86ec47e36b3d90569d1eaa4771c9939))

### Enhancements made

- Support for overrides.json5 [#179](https://github.com/jupyterlab/jupyterlab_server/pull/179) ([@mlucool](https://github.com/mlucool))

### Documentation improvements

- Make LabConfig configurable and add config API docs [#172](https://github.com/jupyterlab/jupyterlab_server/pull/172) ([@afshin](https://github.com/afshin))

### Other merged PRs

- Upgrade packaging [#178](https://github.com/jupyterlab/jupyterlab_server/pull/178) ([@jtpio](https://github.com/jtpio))
- Add more API docs [#177](https://github.com/jupyterlab/jupyterlab_server/pull/177) ([@jtpio](https://github.com/jtpio))
- Add cli config options documentation [#176](https://github.com/jupyterlab/jupyterlab_server/pull/176) ([@jtpio](https://github.com/jtpio))
- Add example request/responses to REST docs [#174](https://github.com/jupyterlab/jupyterlab_server/pull/174) ([@blink1073](https://github.com/blink1073))
- Add Swagger Docs [#173](https://github.com/jupyterlab/jupyterlab_server/pull/173) ([@jtpio](https://github.com/jtpio))
- Update Readme Badges [#171](https://github.com/jupyterlab/jupyterlab_server/pull/171) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-03-30&to=2021-04-26&type=c))

[@afshin](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Aafshin+updated%3A2021-03-30..2021-04-26&type=Issues) | [@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2021-03-30..2021-04-26&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ajtpio+updated%3A2021-03-30..2021-04-26&type=Issues) | [@mlucool](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Amlucool+updated%3A2021-03-30..2021-04-26&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Awelcome+updated%3A2021-03-30..2021-04-26&type=Issues)

## 2.4.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/2.3.0...1a9681654e627afdb67ec5fe1d6581617b813743))

### Merged PRs

- Add Sphinx docs [#169](https://github.com/jupyterlab/jupyterlab_server/pull/169) ([@afshin](https://github.com/afshin))
- Cleanup unused imports [#165](https://github.com/jupyterlab/jupyterlab_server/pull/165) ([@jtpio](https://github.com/jtpio))
- Fill in missing changelog entries [#164](https://github.com/jupyterlab/jupyterlab_server/pull/164) ([@blink1073](https://github.com/blink1073))
- Improve documentation: Instructions for development and test setups [#130](https://github.com/jupyterlab/jupyterlab_server/pull/130) ([@ZelphirKaltstahl](https://github.com/ZelphirKaltstahl))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-02-19&to=2021-03-30&type=c))

[@afshin](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Aafshin+updated%3A2021-02-19..2021-03-30&type=Issues) | [@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2021-02-19..2021-03-30&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ajtpio+updated%3A2021-02-19..2021-03-30&type=Issues) | [@ZelphirKaltstahl](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3AZelphirKaltstahl+updated%3A2021-02-19..2021-03-30&type=Issues)

## 2.3.0

- Set file_url_prefix trait for opening notebooks directly [#162](https://github.com/jupyterlab/jupyterlab_server/pull/162) ([@afshin](https://github.com/afshin))

## 2.2.1

- Alleviate invalid locale issue by only setting it if language pack exists [#159](https://github.com/jupyterlab/jupyterlab_server/pull/159) ([@krassowski](https://github.com/krassowski))

## 2.2.0

- Add URL and description for federated extension data [#154](https://github.com/jupyterlab/jupyterlab_server/pull/154) ([@krassowski](https://github.com/krassowski))

## 2.1.5

- Fix/cp949 encoding error [#158](https://github.com/jupyterlab/jupyterlab_server/pull/158) (@k-takanori)

## 2.1.4

- Reduce path length of installed package [#157](https://github.com/jupyterlab/jupyterlab_server/pull/157) ([@afshin](https://github.com/afshin))

## 2.1.3

- Fix mathjax URL handling [#153](https://github.com/jupyterlab/jupyterlab_server/pull/153) ([@afshin](https://github.com/afshin))

## 2.1.2

- Handle mathjax_url properly [#150](https://github.com/jupyterlab/jupyterlab_server/pull/150) ([@afshin](https://github.com/afshin))

## 2.1.1

- Move open_browser to ProcessApp class [#149](https://github.com/jupyterlab/jupyterlab_server/pull/149) ([@jasongrout](https://github.com/jasongrout))

## 2.1.0

- PR: Add translation managers for server side translation [#136](https://github.com/jupyterlab/jupyterlab_server/pull/136) ([@goanpeca](https://github.com/goanpeca))

## 2.0.0

- Update jupyter*server requirement to 1.* instead of 1.1.\_ [#144](https://github.com/jupyterlab/jupyterlab_server/pull/144) ([@jasongrout](https://github.com/jasongrout))
- Unpin pytest version [#143](https://github.com/jupyterlab/jupyterlab_server/pull/143) ([@afshin](https://github.com/afshin))
- don't patch event loop for tornado 6.1+ [#142](https://github.com/jupyterlab/jupyterlab_server/pull/142) ([@bollwyvl](https://github.com/bollwyvl))
- Update for new jupyter_server pytest plugin interface [#141](https://github.com/jupyterlab/jupyterlab_server/pull/141) ([@afshin](https://github.com/afshin))
- Handle source extensions that are disabled [#140](https://github.com/jupyterlab/jupyterlab_server/pull/140) ([@afshin](https://github.com/afshin))
- Fix var name typo from prev commit [#139](https://github.com/jupyterlab/jupyterlab_server/pull/139) ([@ajbozarth](https://github.com/ajbozarth))
- Ensure there is a disabled_key [#138](https://github.com/jupyterlab/jupyterlab_server/pull/138) ([@afshin](https://github.com/afshin))
- Update page_config handling [#137](https://github.com/jupyterlab/jupyterlab_server/pull/137) ([@afshin](https://github.com/afshin))
- Remove out of date LICENSE reference to json_minify [#135](https://github.com/jupyterlab/jupyterlab_server/pull/135) ([@afshin](https://github.com/afshin))
- Respect environment for page_config.json [#133](https://github.com/jupyterlab/jupyterlab_server/pull/133) ([@afshin](https://github.com/afshin))
- Support a metadata file in the lab extension directory [#132](https://github.com/jupyterlab/jupyterlab_server/pull/132) ([@jasongrout](https://github.com/jasongrout))
- Fixed bug where disabled extensions still ran [#131](https://github.com/jupyterlab/jupyterlab_server/pull/131) ([@ajbozarth](https://github.com/ajbozarth))
- dynamic => federated [#127](https://github.com/jupyterlab/jupyterlab_server/pull/127) ([@afshin](https://github.com/afshin))
- Bump jupyter_server dependency [#126](https://github.com/jupyterlab/jupyterlab_server/pull/126) ([@afshin](https://github.com/afshin))
- Add schemas to settings list [#125](https://github.com/jupyterlab/jupyterlab_server/pull/125) ([@afshin](https://github.com/afshin))
- Add handling of incomplete dynamic extension data [#124](https://github.com/jupyterlab/jupyterlab_server/pull/124) ([@blink1073](https://github.com/blink1073))
- Clean up handling of config [#123](https://github.com/jupyterlab/jupyterlab_server/pull/123) ([@blink1073](https://github.com/blink1073))
- Allow default setting overrides to be configurable in jupyter config [#122](https://github.com/jupyterlab/jupyterlab_server/pull/122) ([@blink1073](https://github.com/blink1073))
- Cache lab extension assets by default [#121](https://github.com/jupyterlab/jupyterlab_server/pull/121) ([@jasongrout](https://github.com/jasongrout))
- Added support for fullStaticUrl and fix handling of base_url [#120](https://github.com/jupyterlab/jupyterlab_server/pull/120) ([@Zsailer](https://github.com/Zsailer))
- Update minimum python version to 3.6 [#119](https://github.com/jupyterlab/jupyterlab_server/pull/119) ([@jasongrout](https://github.com/jasongrout))
- app_version should be a trait [#117](https://github.com/jupyterlab/jupyterlab_server/pull/117) ([@echarles](https://github.com/echarles))
- Use tilde for server requirement [#116](https://github.com/jupyterlab/jupyterlab_server/pull/116) ([@blink1073](https://github.com/blink1073))
- fix spurious logging issue [#115](https://github.com/jupyterlab/jupyterlab_server/pull/115) ([@Zsailer](https://github.com/Zsailer))
- Change payload parsing to accept JSON5 as raw string in JSON payload [#114](https://github.com/jupyterlab/jupyterlab_server/pull/114) ([@blink1073](https://github.com/blink1073))
- Use blocked/allowed extensions naming in JupyterLab Server [#111](https://github.com/jupyterlab/jupyterlab_server/pull/111) ([@echarles](https://github.com/echarles))
- Fix open_browser for process apps [#110](https://github.com/jupyterlab/jupyterlab_server/pull/110) ([@blink1073](https://github.com/blink1073))
- Add handling of dynamic labextensions [#109](https://github.com/jupyterlab/jupyterlab_server/pull/109) ([@blink1073](https://github.com/blink1073))
- UTF-8 all over, test with big unicode string [#108](https://github.com/jupyterlab/jupyterlab_server/pull/108) ([@bollwyvl](https://github.com/bollwyvl))
- fix file mtime/ctime confusion, restore win3.8, patch event loop [#107](https://github.com/jupyterlab/jupyterlab_server/pull/107) ([@bollwyvl](https://github.com/bollwyvl))
- PR: Add other OS and update py versions [#102](https://github.com/jupyterlab/jupyterlab_server/pull/102) ([@goanpeca](https://github.com/goanpeca))
- Changes needed for improved single document mode [#101](https://github.com/jupyterlab/jupyterlab_server/pull/101) ([@ellisonbg](https://github.com/ellisonbg))
- PR: Add CI with github [#100](https://github.com/jupyterlab/jupyterlab_server/pull/100) ([@goanpeca](https://github.com/goanpeca))
- Add last_modified and created to settings and workspace API items [#99](https://github.com/jupyterlab/jupyterlab_server/pull/99) ([@bollwyvl](https://github.com/bollwyvl))
- PR: Add a translations handler [#96](https://github.com/jupyterlab/jupyterlab_server/pull/96) ([@goanpeca](https://github.com/goanpeca))
- JupyterLab Server as Server Extension [#79](https://github.com/jupyterlab/jupyterlab_server/pull/79) ([@echarles](https://github.com/echarles))

## 1.2.0

- Expose settings API to other handlers. [#94](https://github.com/jupyterlab/jupyterlab_server/pull/94) ([@goanpeca](https://github.com/goanpeca))

## 1.1.5

- Always wait for process to finish [#93](https://github.com/jupyterlab/jupyterlab_server/pull/93) ([@blink1073](https://github.com/blink1073))
- Backport PR #91 on branch 1.0.x (Clean up terminate logic) [#92](https://github.com/jupyterlab/jupyterlab_server/pull/92) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- ensure the 'WHICH' command returns absolute path instead of relative path [#72](https://github.com/jupyterlab/jupyterlab_server/pull/72) ([@tgrout](https://github.com/tgrout))

## v1.1.4

- Clean up terminate logic [#91](https://github.com/jupyterlab/jupyterlab_server/pull/91) ([@blink1073](https://github.com/blink1073))

## v1.1.2

- Start a Change Log [#90](https://github.com/jupyterlab/jupyterlab_server/pull/90) ([@blink1073](https://github.com/blink1073))
- Backport PR #88 on branch 1.0.x (Kill the subprocess if it does not stop) [#89](https://github.com/jupyterlab/jupyterlab_server/pull/89) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Kill the subprocess if it does not stop [#88](https://github.com/jupyterlab/jupyterlab_server/pull/88) ([@blink1073](https://github.com/blink1073))

## v1.1.1

- Do not try to close the watch process file handle [#85](https://github.com/jupyterlab/jupyterlab_server/pull/85) ([@blink1073](https://github.com/blink1073))
- Update nodejs error message to not give an outdated version. [#84](https://github.com/jupyterlab/jupyterlab_server/pull/84) ([@jasongrout](https://github.com/jasongrout))

## v1.0.9

- Backport PR #91 on branch 1.0.x (Clean up terminate logic) [#92](https://github.com/jupyterlab/jupyterlab_server/pull/92) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Clean up terminate logic [#91](https://github.com/jupyterlab/jupyterlab_server/pull/91) ([@blink1073](https://github.com/blink1073))

## v1.0.8

- Start a Change Log [#90](https://github.com/jupyterlab/jupyterlab_server/pull/90) ([@blink1073](https://github.com/blink1073))
- Backport PR #88 on branch 1.0.x (Kill the subprocess if it does not stop) [#89](https://github.com/jupyterlab/jupyterlab_server/pull/89) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Kill the subprocess if it does not stop [#88](https://github.com/jupyterlab/jupyterlab_server/pull/88) ([@blink1073](https://github.com/blink1073))
- Do not try to close the watch process file handle [#85](https://github.com/jupyterlab/jupyterlab_server/pull/85) ([@blink1073](https://github.com/blink1073))
- Update nodejs error message to not give an outdated version. [#84](https://github.com/jupyterlab/jupyterlab_server/pull/84) ([@jasongrout](https://github.com/jasongrout))
- Black and White Listings Handler [#82](https://github.com/jupyterlab/jupyterlab_server/pull/82) ([@echarles](https://github.com/echarles))

## v1.0.7

- Fix URL prefixing for absolute URLs [#81](https://github.com/jupyterlab/jupyterlab_server/pull/81) ([@santiagobasulto](https://github.com/santiagobasulto))

## v1.0.6

- Add .json.orig files to sdists [#78](https://github.com/jupyterlab/jupyterlab_server/pull/78) ([@toddrme2178](https://github.com/toddrme2178))

## v1.0.5

- Require jinja2 2.10+ to fix extra escaping [#77](https://github.com/jupyterlab/jupyterlab_server/pull/77) ([@blink1073](https://github.com/blink1073))

## v1.0.4

- Use escape instead of urlencode for urls [#76](https://github.com/jupyterlab/jupyterlab_server/pull/76) ([@blink1073](https://github.com/blink1073))

## v1.0.3

- Escape template values in Jinja [#75](https://github.com/jupyterlab/jupyterlab_server/pull/75) ([@jasongrout](https://github.com/jasongrout))

## v1.0.2

- Add store ID to page config [#74](https://github.com/jupyterlab/jupyterlab_server/pull/74) ([@saulshanabrook](https://github.com/saulshanabrook))

## v1.0.1

- fix page config escaping [#73](https://github.com/jupyterlab/jupyterlab_server/pull/73) ([@nicorikken](https://github.com/nicorikken))

## v1.0.0

- Use json5 to load settings files. [#71](https://github.com/jupyterlab/jupyterlab_server/pull/71) ([@ian-r-rose](https://github.com/ian-r-rose))
- Cleanup for 1.0 [#70](https://github.com/jupyterlab/jupyterlab_server/pull/70) ([@blink1073](https://github.com/blink1073))
- A 403.html file. Should close jupyterlab issue#6065 [#69](https://github.com/jupyterlab/jupyterlab_server/pull/69) ([@zerline](https://github.com/zerline))

## v0.3.4

- Stop using base_url in workspace name. [#68](https://github.com/jupyterlab/jupyterlab_server/pull/68) ([@afshin](https://github.com/afshin))
- v0.3.3 [#67](https://github.com/jupyterlab/jupyterlab_server/pull/67) ([@afshin](https://github.com/afshin))

## v0.13.1

- Cleanup [#56](https://github.com/jupyterlab/jupyterlab_server/pull/56) ([@blink1073](https://github.com/blink1073))

## v0.13.0

- Switch to Python 3.5+ [#55](https://github.com/jupyterlab/jupyterlab_server/pull/55) ([@blink1073](https://github.com/blink1073))
- Switch to jupyter_server [#49](https://github.com/jupyterlab/jupyterlab_server/pull/49) ([@SylvainCorlay](https://github.com/SylvainCorlay))

## v0.12.1

- Fix PY2 handing of potential non-unicode paths being slugified. [#54](https://github.com/jupyterlab/jupyterlab_server/pull/54) ([@afshin](https://github.com/afshin))

## v0.11.2

- Improve use of process quiet flag [#46](https://github.com/jupyterlab/jupyterlab_server/pull/46) ([@vidartf](https://github.com/vidartf))

## v0.11.0

- Include LICENSE file in wheels [#45](https://github.com/jupyterlab/jupyterlab_server/pull/45) ([@toddrme2178](https://github.com/toddrme2178))
- move process utilities from jupyterlab to jupyterlab_launcher [#44](https://github.com/jupyterlab/jupyterlab_server/pull/44) ([@ivanov](https://github.com/ivanov))
- Update test for tornado 5 [#43](https://github.com/jupyterlab/jupyterlab_server/pull/43) ([@blink1073](https://github.com/blink1073))
- Include plugin/schema name in error messages. [#39](https://github.com/jupyterlab/jupyterlab_server/pull/39) ([@afshin](https://github.com/afshin))

## v0.10.5

- Include test assets in sdist [#42](https://github.com/jupyterlab/jupyterlab_server/pull/42) ([@hroncok](https://github.com/hroncok))

## v0.10.3

- Fix the URL patterns: ujoin() creates slashes. [#38](https://github.com/jupyterlab/jupyterlab_server/pull/38) ([@afshin](https://github.com/afshin))

## v0.10.2

- Bug fix: base_url was used twice. [#36](https://github.com/jupyterlab/jupyterlab_server/pull/36) ([@afshin](https://github.com/afshin))

## v0.10.1

- Don't have NotFoundHandler match lab\* [#35](https://github.com/jupyterlab/jupyterlab_server/pull/35) ([@vidartf](https://github.com/vidartf))

## v0.10.0

- Workspaces [#34](https://github.com/jupyterlab/jupyterlab_server/pull/34) ([@afshin](https://github.com/afshin))

## v0.9.1

- Fix path handling on Windows [#33](https://github.com/jupyterlab/jupyterlab_server/pull/33) ([@blink1073](https://github.com/blink1073))

## v0.8.0

- Add a theme handler [#32](https://github.com/jupyterlab/jupyterlab_server/pull/32) ([@blink1073](https://github.com/blink1073))

## v0.7.0

- Require jsonschema library. [#30](https://github.com/jupyterlab/jupyterlab_server/pull/30) ([@afshin](https://github.com/afshin))
- Allow an admin to override extension schema defaults. [#29](https://github.com/jupyterlab/jupyterlab_server/pull/29) ([@afshin](https://github.com/afshin))
- Remove MathJax and Streamline Handler config [#27](https://github.com/jupyterlab/jupyterlab_server/pull/27) ([@blink1073](https://github.com/blink1073))

## v0.6.0

- Add error message option [#26](https://github.com/jupyterlab/jupyterlab_server/pull/26) ([@blink1073](https://github.com/blink1073))
- Update settings handler to support JSON with comments. [#25](https://github.com/jupyterlab/jupyterlab_server/pull/25) ([@afshin](https://github.com/afshin))

## v0.5.5

- Add console error on error page [#24](https://github.com/jupyterlab/jupyterlab_server/pull/24) ([@blink1073](https://github.com/blink1073))

## v0.5.4

- Clean up static dir handling [#23](https://github.com/jupyterlab/jupyterlab_server/pull/23) ([@blink1073](https://github.com/blink1073))

## v0.5.3

- Do not cache themes [#22](https://github.com/jupyterlab/jupyterlab_server/pull/22) ([@blink1073](https://github.com/blink1073))

## v0.5.2

- Cleanup and handle no assets dir [#20](https://github.com/jupyterlab/jupyterlab_server/pull/20) ([@blink1073](https://github.com/blink1073))

## v0.5.1

- Fix handling of user settings dir [#21](https://github.com/jupyterlab/jupyterlab_server/pull/21) ([@blink1073](https://github.com/blink1073))

## v0.5.0

- Update settings handler to parse complex URL paths. [#19](https://github.com/jupyterlab/jupyterlab_server/pull/19) ([@afshin](https://github.com/afshin))

## v0.4.2

- Remove trailing slash to fix theme relative urls [#18](https://github.com/jupyterlab/jupyterlab_server/pull/18) ([@blink1073](https://github.com/blink1073))

## v0.4.1

- Do not cache the static files [#17](https://github.com/jupyterlab/jupyterlab_server/pull/17) ([@blink1073](https://github.com/blink1073))

## v0.4.0

- Theme and settings [#16](https://github.com/jupyterlab/jupyterlab_server/pull/16) ([@blink1073](https://github.com/blink1073))

## v0.3.0

- Switch to a static namespace for webpack files [#13](https://github.com/jupyterlab/jupyterlab_server/pull/13) ([@blink1073](https://github.com/blink1073))

## v0.2.9

- We do not need to encode server provided urls [#12](https://github.com/jupyterlab/jupyterlab_server/pull/12) ([@blink1073](https://github.com/blink1073))
- Add simple travis file [#11](https://github.com/jupyterlab/jupyterlab_server/pull/11) ([@blink1073](https://github.com/blink1073))

## v0.2.8

- Fix addition of public path handler [#9](https://github.com/jupyterlab/jupyterlab_server/pull/9) ([@blink1073](https://github.com/blink1073))
- Add backwards compatibility for public url [#8](https://github.com/jupyterlab/jupyterlab_server/pull/8) ([@blink1073](https://github.com/blink1073))

## v0.2.7

- Fix handling of page config [#7](https://github.com/jupyterlab/jupyterlab_server/pull/7) ([@blink1073](https://github.com/blink1073))

## v0.2.6

- Fix handling of base and ws urls [#6](https://github.com/jupyterlab/jupyterlab_server/pull/6) ([@blink1073](https://github.com/blink1073))

## v0.2.4

- Escape strings in jupyter-config-data json [#5](https://github.com/jupyterlab/jupyterlab_server/pull/5) ([@seibs](https://github.com/seibs))

## v0.2.1

- Fix handling of data [#4](https://github.com/jupyterlab/jupyterlab_server/pull/4) ([@blink1073](https://github.com/blink1073))

## v0.2.0

- Clean up config handling [#3](https://github.com/jupyterlab/jupyterlab_server/pull/3) ([@blink1073](https://github.com/blink1073))
